/*
  marker.h
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __MARKER_H__
#define __MARKER_H__

#include "qgmap.h"
#include <qpixmap.h>
#include "pos.h"
#include "layeredwidget.h"

#define MARKER_SIZE 16
#define ARROW_SIZE 8

#define M_TOP 22
#define M_BOTTOM 30
#define M_LEFT 10
#define M_RIGHT 45

#define M_ARROW_LEN 12
#define M_ARROW_LEN45 9

#define MARKER_FILE APP_PATH "/marker.png"

#define IS_MARKER_BIT(a) (marker_bit&(1<<(a)))
#define MARKER_TOGGLE(a) (marker_bit ^= 1<<(a))

class Marker : public LayeredWidget
{
	Q_OBJECT
  public:
	Marker(LayeredBase *parent, const char *name=0);
	~Marker();

	bool paintEvent(QPaintEvent *e, QPixmap &scr);
	void drawMarker(QPixmap *scr, Pos pos, int index);
	void showEvent();

	void timerEvent( QTimerEvent *e );
	bool keyPressEvent ( QKeyEvent * e );

  protected:
	Pos center;

	Pos saved_pos[10];

	QPixmap base;
	QPixmap arrow[9];
	QPixmap gps_arrow[12];

	void drawBase(QPixmap *scr, int cx, int cy, int index);
	QPixmap &getArrow(int deg);

	bool isClip(QPixmap *scr, int sx ,int sy);
	void drawClipMarker(QPixmap *scr, int sx, int sy, int index);
	void drawClipGPSMarker(QPixmap *scr, int sx, int sy, int index);

	void getMarkerpos(int dx, int dy, int max_x, int max_y,
					  int *mx, int *my, int *ax, int *ay);

	void dispMarkerInfo();
	Pos getPosition(int i);

	bool marker_on;
	int marker_bit;
	enum {MAP=0, GPS};
	int marker_mode;

	bool key_marker_mode;

	int marker_timer_id;

  public slots:
	void setPosition(Pos &);
	void setConfig(const QString &key, const QString &value);
};

#endif // __MARKER_H__
